==> 0.0.1%2B1.tar.gz: lib/models/IR5ArtCategory.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

// --------------------------------------------------------------------------------
part 'IR5ArtCategory.g.dart';

/** Articles Categories */
@JsonSerializable(explicitToJson: true)
class IR5ArtCategory {
  IR5ArtCategory({
    required this.Num,
    required this.Nom,
    required this.Description,
    required this.NomLg1,
    required this.NomLg2,
    required this.NomLg3,
    required this.ExtRef,
    required this.Tags,
    required this.WebOrder,
    required this.NomWebLg1,
    required this.NomWebLg2,
    required this.NomWebLg3,
    required this.WebDescrLg1,
    required this.WebDescrLg2,
    required this.WebDescrLg3,
    required this.Desti,
    required this.PLUDefTVA,
    required this.PLUDefTVAEmport,
    required this.BtnProp,
    required this.Flags,
  });

  factory IR5ArtCategory.fromJson(Map<String, dynamic>? json) => _$IR5ArtCategoryFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ArtCategoryToJson(this);

  @JsonKey(defaultValue: '')
  final String Num;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomLg1;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomLg2;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomLg3;

  /** External Ref (used as primary key) */
  @JsonKey(defaultValue: '')
  final String ExtRef;

  /** Free Tags or Labels semicolumn separated */
  @JsonKey(defaultValue: '')
  final String Tags;

  /** Export to WebOrder Platforms (semicolumn separated list of Platforms)
   * Export ModePay if ModePay.WebOrder
   * Export Article if Article.WebOrder or Article.Categ.WebOrder or Article.Group.WebOrder
   */
  @JsonKey(defaultValue: '')
  final String WebOrder;

  /** Categorie WebName in Lg1. Coalesce to Nom[Lg1]. In Import will also Set Nom[Lg] if Nom[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg1;

  /** Categorie WebName in Lg2. Coalesce to Nom[Lg2]. In Import will also Set Nom[Lg] if Nom[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg2;

  /** Categorie WebName in Lg3. Coalesce to Nom[Lg3]. In Import will also Set Nom[Lg] if Nom[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg3;

  /** Categorie Web Memo Description in Lg1. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg1;

  /** Categorie Web Memo Description in Lg2. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg2;

  /** Categorie Web Memo Description in Lg3. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg3;
  @JsonKey(defaultValue: 0)
  final num Desti;
  @JsonKey(defaultValue: 0)
  final num PLUDefTVA;
  @JsonKey(defaultValue: 0)
  final num PLUDefTVAEmport;

  final IR5BtnProperties? BtnProp;

  /** Art.Categ Flags
   *   Bit 00 : DefineCheckLevel
   *   Bit 01 : DefineCvtsLevel
   *   Bit 10 : OrderByPLU
   *   Bit 11 : OrderByNom
   *   Bit 12 : OrderByCategPos
   *   Bit 18 : NonFood
   *   Bit 19 : Alcool
   *   Bit 20 : Deluxe
   *   Bit 30 : StayInCateg
   *   Bit 31 : GotoSearchList
   *   Bit 40 : StartWaitCateg
   */
  @JsonKey(defaultValue: 0)
  final num Flags;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5ArtCategory.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

// --------------------------------------------------------------------------------
part 'IR5ArtCategory.g.dart';

/** Articles Categories */
@JsonSerializable(explicitToJson: true)
class IR5ArtCategory {
  IR5ArtCategory({
    required this.Num,
    required this.Nom,
    required this.Description,
    required this.NomLg1,
    required this.NomLg2,
    required this.NomLg3,
    required this.ExtRef,
    required this.Tags,
    required this.WebOrder,
    required this.NomWebLg1,
    required this.NomWebLg2,
    required this.NomWebLg3,
    required this.WebDescrLg1,
    required this.WebDescrLg2,
    required this.WebDescrLg3,
    required this.Desti,
    required this.PLUDefTVA,
    required this.PLUDefTVAEmport,
    required this.BtnProp,
    required this.Flags,
  });

  factory IR5ArtCategory.fromJson(Map<String, dynamic>? json) =>
      _$IR5ArtCategoryFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ArtCategoryToJson(this);

  @JsonKey(defaultValue: '')
  final String Num;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomLg1;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomLg2;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomLg3;

  /** External Ref (used as primary key) */
  @JsonKey(defaultValue: '')
  final String ExtRef;

  /** Free Tags or Labels semicolumn separated */
  @JsonKey(defaultValue: '')
  final String Tags;

  /** Export to WebOrder Platforms (semicolumn separated list of Platforms)
   * Export ModePay if ModePay.WebOrder
   * Export Article if Article.WebOrder or Article.Categ.WebOrder or Article.Group.WebOrder
   */
  @JsonKey(defaultValue: '')
  final String WebOrder;

  /** Categorie WebName in Lg1. Coalesce to Nom[Lg1]. In Import will also Set Nom[Lg] if Nom[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg1;

  /** Categorie WebName in Lg2. Coalesce to Nom[Lg2]. In Import will also Set Nom[Lg] if Nom[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg2;

  /** Categorie WebName in Lg3. Coalesce to Nom[Lg3]. In Import will also Set Nom[Lg] if Nom[Lg] Not Set */
  @JsonKey(defaultValue: '')
  final String NomWebLg3;

  /** Categorie Web Memo Description in Lg1. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg1;

  /** Categorie Web Memo Description in Lg2. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg2;

  /** Categorie Web Memo Description in Lg3. Coalesce to Description */
  @JsonKey(defaultValue: '')
  final String WebDescrLg3;
  @JsonKey(defaultValue: 0)
  final num Desti;
  @JsonKey(defaultValue: 0)
  final num PLUDefTVA;
  @JsonKey(defaultValue: 0)
  final num PLUDefTVAEmport;

  final IR5BtnProperties? BtnProp;

  /** Art.Categ Flags
   *   Bit 00 : DefineCheckLevel
   *   Bit 01 : DefineCvtsLevel
   *   Bit 10 : OrderByPLU
   *   Bit 11 : OrderByNom
   *   Bit 12 : OrderByCategPos
   *   Bit 18 : NonFood
   *   Bit 19 : Alcool
   *   Bit 20 : Deluxe
   *   Bit 30 : StayInCateg
   *   Bit 31 : GotoSearchList
   *   Bit 40 : StartWaitCateg
   */
  @JsonKey(defaultValue: 0)
  final num Flags;
}
